pub struct PbrStrategy { /* private fields */ }Trait Implementations
Sourceimpl Default for PbrStrategy
impl Default for PbrStrategy
Sourceimpl ShadingStrategy for PbrStrategy
impl ShadingStrategy for PbrStrategy
Sourcefn name(&self) -> &'static str
fn name(&self) -> &'static str
Stable name used for lookup in
StrategyRegistry and stored on
Material::strategy.Sourcefn requirements(&self) -> &Requirements
fn requirements(&self) -> &Requirements
What this strategy needs from a material to be able to resolve it.
Sourcefn fields(&self) -> &[FieldDesc]
fn fields(&self) -> &[FieldDesc]
The fields this strategy produces, in a fixed order.
resolve()
returns one value per field, in this same order.Sourcefn resolve(
&self,
material: &Material,
) -> Result<Vec<MaterialValue>, MaterialError>
fn resolve( &self, material: &Material, ) -> Result<Vec<MaterialValue>, MaterialError>
Resolves this material’s value for every field in
fields(),
applying this strategy’s own fallbacks for missing properties.Auto Trait Implementations
impl Freeze for PbrStrategy
impl RefUnwindSafe for PbrStrategy
impl Send for PbrStrategy
impl Sync for PbrStrategy
impl Unpin for PbrStrategy
impl UnsafeUnpin for PbrStrategy
impl UnwindSafe for PbrStrategy